# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VectorSearchEndpointArgs', 'VectorSearchEndpoint']

@pulumi.input_type
class VectorSearchEndpointArgs:
    def __init__(__self__, *,
                 endpoint_type: pulumi.Input[_builtins.str],
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a VectorSearchEndpoint resource.
        :param pulumi.Input[_builtins.str] endpoint_type: Type of Mosaic AI Vector Search Endpoint.  Currently only accepting single value: `STANDARD` (See [documentation](https://docs.databricks.com/api/workspace/vectorsearchendpoints/createendpoint) for the list of currently supported values). (Change leads to recreation of the resource).
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this resource.
        :param pulumi.Input[_builtins.str] name: Name of the Mosaic AI Vector Search Endpoint to create. (Change leads to recreation of the resource).
        """
        pulumi.set(__self__, "endpoint_type", endpoint_type)
        if budget_policy_id is not None:
            pulumi.set(__self__, "budget_policy_id", budget_policy_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of Mosaic AI Vector Search Endpoint.  Currently only accepting single value: `STANDARD` (See [documentation](https://docs.databricks.com/api/workspace/vectorsearchendpoints/createendpoint) for the list of currently supported values). (Change leads to recreation of the resource).
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "endpoint_type", value)

    @_builtins.property
    @pulumi.getter(name="budgetPolicyId")
    def budget_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Budget Policy ID set for this resource.
        """
        return pulumi.get(self, "budget_policy_id")

    @budget_policy_id.setter
    def budget_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "budget_policy_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Mosaic AI Vector Search Endpoint to create. (Change leads to recreation of the resource).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _VectorSearchEndpointState:
    def __init__(__self__, *,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 creation_timestamp: Optional[pulumi.Input[_builtins.int]] = None,
                 creator: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint_statuses: Optional[pulumi.Input[Sequence[pulumi.Input['VectorSearchEndpointEndpointStatusArgs']]]] = None,
                 endpoint_type: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated_timestamp: Optional[pulumi.Input[_builtins.int]] = None,
                 last_updated_user: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 num_indexes: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering VectorSearchEndpoint resources.
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this resource.
        :param pulumi.Input[_builtins.int] creation_timestamp: Timestamp of endpoint creation (milliseconds).
        :param pulumi.Input[_builtins.str] creator: Creator of the endpoint.
        :param pulumi.Input[_builtins.str] effective_budget_policy_id: The effective budget policy ID.
        :param pulumi.Input[_builtins.str] endpoint_id: Unique internal identifier of the endpoint (UUID).
        :param pulumi.Input[Sequence[pulumi.Input['VectorSearchEndpointEndpointStatusArgs']]] endpoint_statuses: Object describing the current status of the endpoint consisting of the following fields:
        :param pulumi.Input[_builtins.str] endpoint_type: Type of Mosaic AI Vector Search Endpoint.  Currently only accepting single value: `STANDARD` (See [documentation](https://docs.databricks.com/api/workspace/vectorsearchendpoints/createendpoint) for the list of currently supported values). (Change leads to recreation of the resource).
        :param pulumi.Input[_builtins.int] last_updated_timestamp: Timestamp of the last update to the endpoint (milliseconds).
        :param pulumi.Input[_builtins.str] last_updated_user: User who last updated the endpoint.
        :param pulumi.Input[_builtins.str] name: Name of the Mosaic AI Vector Search Endpoint to create. (Change leads to recreation of the resource).
        :param pulumi.Input[_builtins.int] num_indexes: Number of indexes on the endpoint.
        """
        if budget_policy_id is not None:
            pulumi.set(__self__, "budget_policy_id", budget_policy_id)
        if creation_timestamp is not None:
            pulumi.set(__self__, "creation_timestamp", creation_timestamp)
        if creator is not None:
            pulumi.set(__self__, "creator", creator)
        if effective_budget_policy_id is not None:
            pulumi.set(__self__, "effective_budget_policy_id", effective_budget_policy_id)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if endpoint_statuses is not None:
            pulumi.set(__self__, "endpoint_statuses", endpoint_statuses)
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if last_updated_timestamp is not None:
            pulumi.set(__self__, "last_updated_timestamp", last_updated_timestamp)
        if last_updated_user is not None:
            pulumi.set(__self__, "last_updated_user", last_updated_user)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if num_indexes is not None:
            pulumi.set(__self__, "num_indexes", num_indexes)

    @_builtins.property
    @pulumi.getter(name="budgetPolicyId")
    def budget_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Budget Policy ID set for this resource.
        """
        return pulumi.get(self, "budget_policy_id")

    @budget_policy_id.setter
    def budget_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "budget_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="creationTimestamp")
    def creation_timestamp(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp of endpoint creation (milliseconds).
        """
        return pulumi.get(self, "creation_timestamp")

    @creation_timestamp.setter
    def creation_timestamp(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "creation_timestamp", value)

    @_builtins.property
    @pulumi.getter
    def creator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Creator of the endpoint.
        """
        return pulumi.get(self, "creator")

    @creator.setter
    def creator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator", value)

    @_builtins.property
    @pulumi.getter(name="effectiveBudgetPolicyId")
    def effective_budget_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The effective budget policy ID.
        """
        return pulumi.get(self, "effective_budget_policy_id")

    @effective_budget_policy_id.setter
    def effective_budget_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_budget_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique internal identifier of the endpoint (UUID).
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @_builtins.property
    @pulumi.getter(name="endpointStatuses")
    def endpoint_statuses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VectorSearchEndpointEndpointStatusArgs']]]]:
        """
        Object describing the current status of the endpoint consisting of the following fields:
        """
        return pulumi.get(self, "endpoint_statuses")

    @endpoint_statuses.setter
    def endpoint_statuses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VectorSearchEndpointEndpointStatusArgs']]]]):
        pulumi.set(self, "endpoint_statuses", value)

    @_builtins.property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of Mosaic AI Vector Search Endpoint.  Currently only accepting single value: `STANDARD` (See [documentation](https://docs.databricks.com/api/workspace/vectorsearchendpoints/createendpoint) for the list of currently supported values). (Change leads to recreation of the resource).
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_type", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdatedTimestamp")
    def last_updated_timestamp(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp of the last update to the endpoint (milliseconds).
        """
        return pulumi.get(self, "last_updated_timestamp")

    @last_updated_timestamp.setter
    def last_updated_timestamp(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "last_updated_timestamp", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdatedUser")
    def last_updated_user(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User who last updated the endpoint.
        """
        return pulumi.get(self, "last_updated_user")

    @last_updated_user.setter
    def last_updated_user(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated_user", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Mosaic AI Vector Search Endpoint to create. (Change leads to recreation of the resource).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="numIndexes")
    def num_indexes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of indexes on the endpoint.
        """
        return pulumi.get(self, "num_indexes")

    @num_indexes.setter
    def num_indexes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "num_indexes", value)


@pulumi.type_token("databricks:index/vectorSearchEndpoint:VectorSearchEndpoint")
class VectorSearchEndpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource allows you to create [Mosaic AI Vector Search Endpoint](https://docs.databricks.com/en/generative-ai/vector-search.html) in Databricks.  Mosaic AI Vector Search is a serverless similarity search engine that allows you to store a vector representation of your data, including metadata, in a vector database.  The Mosaic AI Vector Search Endpoint is used to create and access vector search indexes.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.VectorSearchEndpoint("this",
            name="vector-search-test",
            endpoint_type="STANDARD")
        ```

        ## Import

        The resource can be imported using the name of the Mosaic AI Vector Search Endpoint

        hcl

        import {

          to = databricks_vector_search_endpoint.this

          id = "<endpoint-name>"

        }

        Alternatively, when using `terraform` version 1.4 or earlier, import using the `pulumi import` command:

        bash

        ```sh
        $ pulumi import databricks:index/vectorSearchEndpoint:VectorSearchEndpoint this <endpoint-name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this resource.
        :param pulumi.Input[_builtins.str] endpoint_type: Type of Mosaic AI Vector Search Endpoint.  Currently only accepting single value: `STANDARD` (See [documentation](https://docs.databricks.com/api/workspace/vectorsearchendpoints/createendpoint) for the list of currently supported values). (Change leads to recreation of the resource).
        :param pulumi.Input[_builtins.str] name: Name of the Mosaic AI Vector Search Endpoint to create. (Change leads to recreation of the resource).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VectorSearchEndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create [Mosaic AI Vector Search Endpoint](https://docs.databricks.com/en/generative-ai/vector-search.html) in Databricks.  Mosaic AI Vector Search is a serverless similarity search engine that allows you to store a vector representation of your data, including metadata, in a vector database.  The Mosaic AI Vector Search Endpoint is used to create and access vector search indexes.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.VectorSearchEndpoint("this",
            name="vector-search-test",
            endpoint_type="STANDARD")
        ```

        ## Import

        The resource can be imported using the name of the Mosaic AI Vector Search Endpoint

        hcl

        import {

          to = databricks_vector_search_endpoint.this

          id = "<endpoint-name>"

        }

        Alternatively, when using `terraform` version 1.4 or earlier, import using the `pulumi import` command:

        bash

        ```sh
        $ pulumi import databricks:index/vectorSearchEndpoint:VectorSearchEndpoint this <endpoint-name>
        ```

        :param str resource_name: The name of the resource.
        :param VectorSearchEndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VectorSearchEndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VectorSearchEndpointArgs.__new__(VectorSearchEndpointArgs)

            __props__.__dict__["budget_policy_id"] = budget_policy_id
            if endpoint_type is None and not opts.urn:
                raise TypeError("Missing required property 'endpoint_type'")
            __props__.__dict__["endpoint_type"] = endpoint_type
            __props__.__dict__["name"] = name
            __props__.__dict__["creation_timestamp"] = None
            __props__.__dict__["creator"] = None
            __props__.__dict__["effective_budget_policy_id"] = None
            __props__.__dict__["endpoint_id"] = None
            __props__.__dict__["endpoint_statuses"] = None
            __props__.__dict__["last_updated_timestamp"] = None
            __props__.__dict__["last_updated_user"] = None
            __props__.__dict__["num_indexes"] = None
        super(VectorSearchEndpoint, __self__).__init__(
            'databricks:index/vectorSearchEndpoint:VectorSearchEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            creation_timestamp: Optional[pulumi.Input[_builtins.int]] = None,
            creator: Optional[pulumi.Input[_builtins.str]] = None,
            effective_budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint_statuses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VectorSearchEndpointEndpointStatusArgs', 'VectorSearchEndpointEndpointStatusArgsDict']]]]] = None,
            endpoint_type: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated_timestamp: Optional[pulumi.Input[_builtins.int]] = None,
            last_updated_user: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            num_indexes: Optional[pulumi.Input[_builtins.int]] = None) -> 'VectorSearchEndpoint':
        """
        Get an existing VectorSearchEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this resource.
        :param pulumi.Input[_builtins.int] creation_timestamp: Timestamp of endpoint creation (milliseconds).
        :param pulumi.Input[_builtins.str] creator: Creator of the endpoint.
        :param pulumi.Input[_builtins.str] effective_budget_policy_id: The effective budget policy ID.
        :param pulumi.Input[_builtins.str] endpoint_id: Unique internal identifier of the endpoint (UUID).
        :param pulumi.Input[Sequence[pulumi.Input[Union['VectorSearchEndpointEndpointStatusArgs', 'VectorSearchEndpointEndpointStatusArgsDict']]]] endpoint_statuses: Object describing the current status of the endpoint consisting of the following fields:
        :param pulumi.Input[_builtins.str] endpoint_type: Type of Mosaic AI Vector Search Endpoint.  Currently only accepting single value: `STANDARD` (See [documentation](https://docs.databricks.com/api/workspace/vectorsearchendpoints/createendpoint) for the list of currently supported values). (Change leads to recreation of the resource).
        :param pulumi.Input[_builtins.int] last_updated_timestamp: Timestamp of the last update to the endpoint (milliseconds).
        :param pulumi.Input[_builtins.str] last_updated_user: User who last updated the endpoint.
        :param pulumi.Input[_builtins.str] name: Name of the Mosaic AI Vector Search Endpoint to create. (Change leads to recreation of the resource).
        :param pulumi.Input[_builtins.int] num_indexes: Number of indexes on the endpoint.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VectorSearchEndpointState.__new__(_VectorSearchEndpointState)

        __props__.__dict__["budget_policy_id"] = budget_policy_id
        __props__.__dict__["creation_timestamp"] = creation_timestamp
        __props__.__dict__["creator"] = creator
        __props__.__dict__["effective_budget_policy_id"] = effective_budget_policy_id
        __props__.__dict__["endpoint_id"] = endpoint_id
        __props__.__dict__["endpoint_statuses"] = endpoint_statuses
        __props__.__dict__["endpoint_type"] = endpoint_type
        __props__.__dict__["last_updated_timestamp"] = last_updated_timestamp
        __props__.__dict__["last_updated_user"] = last_updated_user
        __props__.__dict__["name"] = name
        __props__.__dict__["num_indexes"] = num_indexes
        return VectorSearchEndpoint(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="budgetPolicyId")
    def budget_policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Budget Policy ID set for this resource.
        """
        return pulumi.get(self, "budget_policy_id")

    @_builtins.property
    @pulumi.getter(name="creationTimestamp")
    def creation_timestamp(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp of endpoint creation (milliseconds).
        """
        return pulumi.get(self, "creation_timestamp")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> pulumi.Output[_builtins.str]:
        """
        Creator of the endpoint.
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter(name="effectiveBudgetPolicyId")
    def effective_budget_policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        The effective budget policy ID.
        """
        return pulumi.get(self, "effective_budget_policy_id")

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique internal identifier of the endpoint (UUID).
        """
        return pulumi.get(self, "endpoint_id")

    @_builtins.property
    @pulumi.getter(name="endpointStatuses")
    def endpoint_statuses(self) -> pulumi.Output[Sequence['outputs.VectorSearchEndpointEndpointStatus']]:
        """
        Object describing the current status of the endpoint consisting of the following fields:
        """
        return pulumi.get(self, "endpoint_statuses")

    @_builtins.property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of Mosaic AI Vector Search Endpoint.  Currently only accepting single value: `STANDARD` (See [documentation](https://docs.databricks.com/api/workspace/vectorsearchendpoints/createendpoint) for the list of currently supported values). (Change leads to recreation of the resource).
        """
        return pulumi.get(self, "endpoint_type")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedTimestamp")
    def last_updated_timestamp(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp of the last update to the endpoint (milliseconds).
        """
        return pulumi.get(self, "last_updated_timestamp")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedUser")
    def last_updated_user(self) -> pulumi.Output[_builtins.str]:
        """
        User who last updated the endpoint.
        """
        return pulumi.get(self, "last_updated_user")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Mosaic AI Vector Search Endpoint to create. (Change leads to recreation of the resource).
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="numIndexes")
    def num_indexes(self) -> pulumi.Output[_builtins.int]:
        """
        Number of indexes on the endpoint.
        """
        return pulumi.get(self, "num_indexes")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDatabaseInstanceResult',
    'AwaitableGetDatabaseInstanceResult',
    'get_database_instance',
    'get_database_instance_output',
]

@pulumi.output_type
class GetDatabaseInstanceResult:
    """
    A collection of values returned by getDatabaseInstance.
    """
    def __init__(__self__, capacity=None, child_instance_refs=None, creation_time=None, creator=None, custom_tags=None, effective_capacity=None, effective_custom_tags=None, effective_enable_pg_native_login=None, effective_enable_readable_secondaries=None, effective_node_count=None, effective_retention_window_in_days=None, effective_stopped=None, effective_usage_policy_id=None, enable_pg_native_login=None, enable_readable_secondaries=None, id=None, name=None, node_count=None, parent_instance_ref=None, pg_version=None, read_only_dns=None, read_write_dns=None, retention_window_in_days=None, state=None, stopped=None, uid=None, usage_policy_id=None):
        if capacity and not isinstance(capacity, str):
            raise TypeError("Expected argument 'capacity' to be a str")
        pulumi.set(__self__, "capacity", capacity)
        if child_instance_refs and not isinstance(child_instance_refs, list):
            raise TypeError("Expected argument 'child_instance_refs' to be a list")
        pulumi.set(__self__, "child_instance_refs", child_instance_refs)
        if creation_time and not isinstance(creation_time, str):
            raise TypeError("Expected argument 'creation_time' to be a str")
        pulumi.set(__self__, "creation_time", creation_time)
        if creator and not isinstance(creator, str):
            raise TypeError("Expected argument 'creator' to be a str")
        pulumi.set(__self__, "creator", creator)
        if custom_tags and not isinstance(custom_tags, list):
            raise TypeError("Expected argument 'custom_tags' to be a list")
        pulumi.set(__self__, "custom_tags", custom_tags)
        if effective_capacity and not isinstance(effective_capacity, str):
            raise TypeError("Expected argument 'effective_capacity' to be a str")
        pulumi.set(__self__, "effective_capacity", effective_capacity)
        if effective_custom_tags and not isinstance(effective_custom_tags, list):
            raise TypeError("Expected argument 'effective_custom_tags' to be a list")
        pulumi.set(__self__, "effective_custom_tags", effective_custom_tags)
        if effective_enable_pg_native_login and not isinstance(effective_enable_pg_native_login, bool):
            raise TypeError("Expected argument 'effective_enable_pg_native_login' to be a bool")
        pulumi.set(__self__, "effective_enable_pg_native_login", effective_enable_pg_native_login)
        if effective_enable_readable_secondaries and not isinstance(effective_enable_readable_secondaries, bool):
            raise TypeError("Expected argument 'effective_enable_readable_secondaries' to be a bool")
        pulumi.set(__self__, "effective_enable_readable_secondaries", effective_enable_readable_secondaries)
        if effective_node_count and not isinstance(effective_node_count, int):
            raise TypeError("Expected argument 'effective_node_count' to be a int")
        pulumi.set(__self__, "effective_node_count", effective_node_count)
        if effective_retention_window_in_days and not isinstance(effective_retention_window_in_days, int):
            raise TypeError("Expected argument 'effective_retention_window_in_days' to be a int")
        pulumi.set(__self__, "effective_retention_window_in_days", effective_retention_window_in_days)
        if effective_stopped and not isinstance(effective_stopped, bool):
            raise TypeError("Expected argument 'effective_stopped' to be a bool")
        pulumi.set(__self__, "effective_stopped", effective_stopped)
        if effective_usage_policy_id and not isinstance(effective_usage_policy_id, str):
            raise TypeError("Expected argument 'effective_usage_policy_id' to be a str")
        pulumi.set(__self__, "effective_usage_policy_id", effective_usage_policy_id)
        if enable_pg_native_login and not isinstance(enable_pg_native_login, bool):
            raise TypeError("Expected argument 'enable_pg_native_login' to be a bool")
        pulumi.set(__self__, "enable_pg_native_login", enable_pg_native_login)
        if enable_readable_secondaries and not isinstance(enable_readable_secondaries, bool):
            raise TypeError("Expected argument 'enable_readable_secondaries' to be a bool")
        pulumi.set(__self__, "enable_readable_secondaries", enable_readable_secondaries)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_count and not isinstance(node_count, int):
            raise TypeError("Expected argument 'node_count' to be a int")
        pulumi.set(__self__, "node_count", node_count)
        if parent_instance_ref and not isinstance(parent_instance_ref, dict):
            raise TypeError("Expected argument 'parent_instance_ref' to be a dict")
        pulumi.set(__self__, "parent_instance_ref", parent_instance_ref)
        if pg_version and not isinstance(pg_version, str):
            raise TypeError("Expected argument 'pg_version' to be a str")
        pulumi.set(__self__, "pg_version", pg_version)
        if read_only_dns and not isinstance(read_only_dns, str):
            raise TypeError("Expected argument 'read_only_dns' to be a str")
        pulumi.set(__self__, "read_only_dns", read_only_dns)
        if read_write_dns and not isinstance(read_write_dns, str):
            raise TypeError("Expected argument 'read_write_dns' to be a str")
        pulumi.set(__self__, "read_write_dns", read_write_dns)
        if retention_window_in_days and not isinstance(retention_window_in_days, int):
            raise TypeError("Expected argument 'retention_window_in_days' to be a int")
        pulumi.set(__self__, "retention_window_in_days", retention_window_in_days)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if stopped and not isinstance(stopped, bool):
            raise TypeError("Expected argument 'stopped' to be a bool")
        pulumi.set(__self__, "stopped", stopped)
        if uid and not isinstance(uid, str):
            raise TypeError("Expected argument 'uid' to be a str")
        pulumi.set(__self__, "uid", uid)
        if usage_policy_id and not isinstance(usage_policy_id, str):
            raise TypeError("Expected argument 'usage_policy_id' to be a str")
        pulumi.set(__self__, "usage_policy_id", usage_policy_id)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> _builtins.str:
        """
        (string) - The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @_builtins.property
    @pulumi.getter(name="childInstanceRefs")
    def child_instance_refs(self) -> Sequence['outputs.GetDatabaseInstanceChildInstanceRefResult']:
        """
        (list of DatabaseInstanceRef) - The refs of the child instances. This is only available if the instance is
        parent instance
        """
        return pulumi.get(self, "child_instance_refs")

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> _builtins.str:
        """
        (string) - The timestamp when the instance was created
        """
        return pulumi.get(self, "creation_time")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> _builtins.str:
        """
        (string) - The email of the creator of the instance
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter(name="customTags")
    def custom_tags(self) -> Sequence['outputs.GetDatabaseInstanceCustomTagResult']:
        """
        (list of CustomTag) - Custom tags associated with the instance. This field is only included on create and update responses
        """
        return pulumi.get(self, "custom_tags")

    @_builtins.property
    @pulumi.getter(name="effectiveCapacity")
    def effective_capacity(self) -> _builtins.str:
        """
        (string, deprecated) - Deprecated. The sku of the instance; this field will always match the value of capacity
        """
        return pulumi.get(self, "effective_capacity")

    @_builtins.property
    @pulumi.getter(name="effectiveCustomTags")
    def effective_custom_tags(self) -> Sequence['outputs.GetDatabaseInstanceEffectiveCustomTagResult']:
        """
        (list of CustomTag) - The recorded custom tags associated with the instance
        """
        return pulumi.get(self, "effective_custom_tags")

    @_builtins.property
    @pulumi.getter(name="effectiveEnablePgNativeLogin")
    def effective_enable_pg_native_login(self) -> _builtins.bool:
        """
        (boolean) - Whether the instance has PG native password login enabled
        """
        return pulumi.get(self, "effective_enable_pg_native_login")

    @_builtins.property
    @pulumi.getter(name="effectiveEnableReadableSecondaries")
    def effective_enable_readable_secondaries(self) -> _builtins.bool:
        """
        (boolean) - Whether secondaries serving read-only traffic are enabled. Defaults to false
        """
        return pulumi.get(self, "effective_enable_readable_secondaries")

    @_builtins.property
    @pulumi.getter(name="effectiveNodeCount")
    def effective_node_count(self) -> _builtins.int:
        """
        (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries
        """
        return pulumi.get(self, "effective_node_count")

    @_builtins.property
    @pulumi.getter(name="effectiveRetentionWindowInDays")
    def effective_retention_window_in_days(self) -> _builtins.int:
        """
        (integer) - The retention window for the instance. This is the time window in days
        for which the historical data is retained
        """
        return pulumi.get(self, "effective_retention_window_in_days")

    @_builtins.property
    @pulumi.getter(name="effectiveStopped")
    def effective_stopped(self) -> _builtins.bool:
        """
        (boolean) - Whether the instance is stopped
        """
        return pulumi.get(self, "effective_stopped")

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> _builtins.str:
        """
        (string) - The policy that is applied to the instance
        """
        return pulumi.get(self, "effective_usage_policy_id")

    @_builtins.property
    @pulumi.getter(name="enablePgNativeLogin")
    def enable_pg_native_login(self) -> _builtins.bool:
        """
        (boolean) - Whether to enable PG native password login on the instance. Defaults to false
        """
        return pulumi.get(self, "enable_pg_native_login")

    @_builtins.property
    @pulumi.getter(name="enableReadableSecondaries")
    def enable_readable_secondaries(self) -> _builtins.bool:
        """
        (boolean) - Whether to enable secondaries to serve read-only traffic. Defaults to false
        """
        return pulumi.get(self, "enable_readable_secondaries")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Name of the ref database instance
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> _builtins.int:
        """
        (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        """
        return pulumi.get(self, "node_count")

    @_builtins.property
    @pulumi.getter(name="parentInstanceRef")
    def parent_instance_ref(self) -> 'outputs.GetDatabaseInstanceParentInstanceRefResult':
        """
        (DatabaseInstanceRef) - The ref of the parent instance. This is only available if the instance is
        child instance.
        Input: For specifying the parent instance to create a child instance. Optional.
        Output: Only populated if provided as input to create a child instance
        """
        return pulumi.get(self, "parent_instance_ref")

    @_builtins.property
    @pulumi.getter(name="pgVersion")
    def pg_version(self) -> _builtins.str:
        """
        (string) - The version of Postgres running on the instance
        """
        return pulumi.get(self, "pg_version")

    @_builtins.property
    @pulumi.getter(name="readOnlyDns")
    def read_only_dns(self) -> _builtins.str:
        """
        (string) - The DNS endpoint to connect to the instance for read only access. This is only available if
        enable_readable_secondaries is true
        """
        return pulumi.get(self, "read_only_dns")

    @_builtins.property
    @pulumi.getter(name="readWriteDns")
    def read_write_dns(self) -> _builtins.str:
        """
        (string) - The DNS endpoint to connect to the instance for read+write access
        """
        return pulumi.get(self, "read_write_dns")

    @_builtins.property
    @pulumi.getter(name="retentionWindowInDays")
    def retention_window_in_days(self) -> _builtins.int:
        """
        (integer) - The retention window for the instance. This is the time window in days
        for which the historical data is retained. The default value is 7 days.
        Valid values are 2 to 35 days
        """
        return pulumi.get(self, "retention_window_in_days")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        (string) - The current state of the instance. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def stopped(self) -> _builtins.bool:
        """
        (boolean) - Whether to stop the instance. An input only param, see effective_stopped for the output
        """
        return pulumi.get(self, "stopped")

    @_builtins.property
    @pulumi.getter
    def uid(self) -> _builtins.str:
        """
        (string) - Id of the ref database instance
        """
        return pulumi.get(self, "uid")

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> _builtins.str:
        """
        (string) - The desired usage policy to associate with the instance
        """
        return pulumi.get(self, "usage_policy_id")


class AwaitableGetDatabaseInstanceResult(GetDatabaseInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseInstanceResult(
            capacity=self.capacity,
            child_instance_refs=self.child_instance_refs,
            creation_time=self.creation_time,
            creator=self.creator,
            custom_tags=self.custom_tags,
            effective_capacity=self.effective_capacity,
            effective_custom_tags=self.effective_custom_tags,
            effective_enable_pg_native_login=self.effective_enable_pg_native_login,
            effective_enable_readable_secondaries=self.effective_enable_readable_secondaries,
            effective_node_count=self.effective_node_count,
            effective_retention_window_in_days=self.effective_retention_window_in_days,
            effective_stopped=self.effective_stopped,
            effective_usage_policy_id=self.effective_usage_policy_id,
            enable_pg_native_login=self.enable_pg_native_login,
            enable_readable_secondaries=self.enable_readable_secondaries,
            id=self.id,
            name=self.name,
            node_count=self.node_count,
            parent_instance_ref=self.parent_instance_ref,
            pg_version=self.pg_version,
            read_only_dns=self.read_only_dns,
            read_write_dns=self.read_write_dns,
            retention_window_in_days=self.retention_window_in_days,
            state=self.state,
            stopped=self.stopped,
            uid=self.uid,
            usage_policy_id=self.usage_policy_id)


def get_database_instance(name: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseInstanceResult:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single Database Instance.

    ## Example Usage

    Referring to a Database Instance by name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_database_instance(name="my-database-instance")
    ```


    :param _builtins.str name: The name of the instance. This is the unique identifier for the instance
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getDatabaseInstance:getDatabaseInstance', __args__, opts=opts, typ=GetDatabaseInstanceResult).value

    return AwaitableGetDatabaseInstanceResult(
        capacity=pulumi.get(__ret__, 'capacity'),
        child_instance_refs=pulumi.get(__ret__, 'child_instance_refs'),
        creation_time=pulumi.get(__ret__, 'creation_time'),
        creator=pulumi.get(__ret__, 'creator'),
        custom_tags=pulumi.get(__ret__, 'custom_tags'),
        effective_capacity=pulumi.get(__ret__, 'effective_capacity'),
        effective_custom_tags=pulumi.get(__ret__, 'effective_custom_tags'),
        effective_enable_pg_native_login=pulumi.get(__ret__, 'effective_enable_pg_native_login'),
        effective_enable_readable_secondaries=pulumi.get(__ret__, 'effective_enable_readable_secondaries'),
        effective_node_count=pulumi.get(__ret__, 'effective_node_count'),
        effective_retention_window_in_days=pulumi.get(__ret__, 'effective_retention_window_in_days'),
        effective_stopped=pulumi.get(__ret__, 'effective_stopped'),
        effective_usage_policy_id=pulumi.get(__ret__, 'effective_usage_policy_id'),
        enable_pg_native_login=pulumi.get(__ret__, 'enable_pg_native_login'),
        enable_readable_secondaries=pulumi.get(__ret__, 'enable_readable_secondaries'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        node_count=pulumi.get(__ret__, 'node_count'),
        parent_instance_ref=pulumi.get(__ret__, 'parent_instance_ref'),
        pg_version=pulumi.get(__ret__, 'pg_version'),
        read_only_dns=pulumi.get(__ret__, 'read_only_dns'),
        read_write_dns=pulumi.get(__ret__, 'read_write_dns'),
        retention_window_in_days=pulumi.get(__ret__, 'retention_window_in_days'),
        state=pulumi.get(__ret__, 'state'),
        stopped=pulumi.get(__ret__, 'stopped'),
        uid=pulumi.get(__ret__, 'uid'),
        usage_policy_id=pulumi.get(__ret__, 'usage_policy_id'))
def get_database_instance_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseInstanceResult]:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single Database Instance.

    ## Example Usage

    Referring to a Database Instance by name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_database_instance(name="my-database-instance")
    ```


    :param _builtins.str name: The name of the instance. This is the unique identifier for the instance
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getDatabaseInstance:getDatabaseInstance', __args__, opts=opts, typ=GetDatabaseInstanceResult)
    return __ret__.apply(lambda __response__: GetDatabaseInstanceResult(
        capacity=pulumi.get(__response__, 'capacity'),
        child_instance_refs=pulumi.get(__response__, 'child_instance_refs'),
        creation_time=pulumi.get(__response__, 'creation_time'),
        creator=pulumi.get(__response__, 'creator'),
        custom_tags=pulumi.get(__response__, 'custom_tags'),
        effective_capacity=pulumi.get(__response__, 'effective_capacity'),
        effective_custom_tags=pulumi.get(__response__, 'effective_custom_tags'),
        effective_enable_pg_native_login=pulumi.get(__response__, 'effective_enable_pg_native_login'),
        effective_enable_readable_secondaries=pulumi.get(__response__, 'effective_enable_readable_secondaries'),
        effective_node_count=pulumi.get(__response__, 'effective_node_count'),
        effective_retention_window_in_days=pulumi.get(__response__, 'effective_retention_window_in_days'),
        effective_stopped=pulumi.get(__response__, 'effective_stopped'),
        effective_usage_policy_id=pulumi.get(__response__, 'effective_usage_policy_id'),
        enable_pg_native_login=pulumi.get(__response__, 'enable_pg_native_login'),
        enable_readable_secondaries=pulumi.get(__response__, 'enable_readable_secondaries'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        node_count=pulumi.get(__response__, 'node_count'),
        parent_instance_ref=pulumi.get(__response__, 'parent_instance_ref'),
        pg_version=pulumi.get(__response__, 'pg_version'),
        read_only_dns=pulumi.get(__response__, 'read_only_dns'),
        read_write_dns=pulumi.get(__response__, 'read_write_dns'),
        retention_window_in_days=pulumi.get(__response__, 'retention_window_in_days'),
        state=pulumi.get(__response__, 'state'),
        stopped=pulumi.get(__response__, 'stopped'),
        uid=pulumi.get(__response__, 'uid'),
        usage_policy_id=pulumi.get(__response__, 'usage_policy_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SystemSchemaArgs', 'SystemSchema']

@pulumi.input_type
class SystemSchemaArgs:
    def __init__(__self__, *,
                 schema: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a SystemSchema resource.
        :param pulumi.Input[_builtins.str] schema: name of the system schema.
        """
        pulumi.set(__self__, "schema", schema)

    @_builtins.property
    @pulumi.getter
    def schema(self) -> pulumi.Input[_builtins.str]:
        """
        name of the system schema.
        """
        return pulumi.get(self, "schema")

    @schema.setter
    def schema(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "schema", value)


@pulumi.input_type
class _SystemSchemaState:
    def __init__(__self__, *,
                 auto_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 full_name: Optional[pulumi.Input[_builtins.str]] = None,
                 metastore_id: Optional[pulumi.Input[_builtins.str]] = None,
                 schema: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SystemSchema resources.
        :param pulumi.Input[_builtins.str] full_name: the full name of the system schema, in form of `system.<schema>`.
        :param pulumi.Input[_builtins.str] schema: name of the system schema.
        :param pulumi.Input[_builtins.str] state: The current state of enablement for the system schema.
        """
        if auto_enabled is not None:
            pulumi.set(__self__, "auto_enabled", auto_enabled)
        if full_name is not None:
            pulumi.set(__self__, "full_name", full_name)
        if metastore_id is not None:
            pulumi.set(__self__, "metastore_id", metastore_id)
        if schema is not None:
            pulumi.set(__self__, "schema", schema)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter(name="autoEnabled")
    def auto_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "auto_enabled")

    @auto_enabled.setter
    def auto_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_enabled", value)

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        the full name of the system schema, in form of `system.<schema>`.
        """
        return pulumi.get(self, "full_name")

    @full_name.setter
    def full_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "full_name", value)

    @_builtins.property
    @pulumi.getter(name="metastoreId")
    def metastore_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "metastore_id")

    @metastore_id.setter
    def metastore_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "metastore_id", value)

    @_builtins.property
    @pulumi.getter
    def schema(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of the system schema.
        """
        return pulumi.get(self, "schema")

    @schema.setter
    def schema(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "schema", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The current state of enablement for the system schema.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)


@pulumi.type_token("databricks:index/systemSchema:SystemSchema")
class SystemSchema(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 schema: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages system tables enablement. System tables are a Databricks-hosted analytical store of your account's operational data. System tables can be used for historical observability across your account. System tables must be enabled by an account admin.

        > This resource can only be used with a workspace-level provider!

        > Certain system schemas (such as `billing`) may be auto-enabled once GA and should not be manually declared in Pulumi configurations.  Certain schemas can't also be disabled completely.

        ## Example Usage

        Enable the system schema `access`

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.SystemSchema("this", schema="access")
        ```

        ## Import

        This resource can be imported by the metastore id and schema name:

        hcl

        import {

          to = databricks_system_schema.this

          id = "<metastore_id>|<schema_name>"

        }

        Alternatively, when using `terraform` version 1.4 or earlier, import using the `pulumi import` command:

        bash

        ```sh
        $ pulumi import databricks:index/systemSchema:SystemSchema this '<metastore_id>|<schema_name>'
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] schema: name of the system schema.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SystemSchemaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages system tables enablement. System tables are a Databricks-hosted analytical store of your account's operational data. System tables can be used for historical observability across your account. System tables must be enabled by an account admin.

        > This resource can only be used with a workspace-level provider!

        > Certain system schemas (such as `billing`) may be auto-enabled once GA and should not be manually declared in Pulumi configurations.  Certain schemas can't also be disabled completely.

        ## Example Usage

        Enable the system schema `access`

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.SystemSchema("this", schema="access")
        ```

        ## Import

        This resource can be imported by the metastore id and schema name:

        hcl

        import {

          to = databricks_system_schema.this

          id = "<metastore_id>|<schema_name>"

        }

        Alternatively, when using `terraform` version 1.4 or earlier, import using the `pulumi import` command:

        bash

        ```sh
        $ pulumi import databricks:index/systemSchema:SystemSchema this '<metastore_id>|<schema_name>'
        ```

        :param str resource_name: The name of the resource.
        :param SystemSchemaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SystemSchemaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 schema: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SystemSchemaArgs.__new__(SystemSchemaArgs)

            if schema is None and not opts.urn:
                raise TypeError("Missing required property 'schema'")
            __props__.__dict__["schema"] = schema
            __props__.__dict__["auto_enabled"] = None
            __props__.__dict__["full_name"] = None
            __props__.__dict__["metastore_id"] = None
            __props__.__dict__["state"] = None
        super(SystemSchema, __self__).__init__(
            'databricks:index/systemSchema:SystemSchema',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            full_name: Optional[pulumi.Input[_builtins.str]] = None,
            metastore_id: Optional[pulumi.Input[_builtins.str]] = None,
            schema: Optional[pulumi.Input[_builtins.str]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None) -> 'SystemSchema':
        """
        Get an existing SystemSchema resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] full_name: the full name of the system schema, in form of `system.<schema>`.
        :param pulumi.Input[_builtins.str] schema: name of the system schema.
        :param pulumi.Input[_builtins.str] state: The current state of enablement for the system schema.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SystemSchemaState.__new__(_SystemSchemaState)

        __props__.__dict__["auto_enabled"] = auto_enabled
        __props__.__dict__["full_name"] = full_name
        __props__.__dict__["metastore_id"] = metastore_id
        __props__.__dict__["schema"] = schema
        __props__.__dict__["state"] = state
        return SystemSchema(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="autoEnabled")
    def auto_enabled(self) -> pulumi.Output[_builtins.bool]:
        return pulumi.get(self, "auto_enabled")

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> pulumi.Output[_builtins.str]:
        """
        the full name of the system schema, in form of `system.<schema>`.
        """
        return pulumi.get(self, "full_name")

    @_builtins.property
    @pulumi.getter(name="metastoreId")
    def metastore_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "metastore_id")

    @_builtins.property
    @pulumi.getter
    def schema(self) -> pulumi.Output[_builtins.str]:
        """
        name of the system schema.
        """
        return pulumi.get(self, "schema")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        The current state of enablement for the system schema.
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServicePrincipalFederationPolicyArgs', 'ServicePrincipalFederationPolicy']

@pulumi.input_type
class ServicePrincipalFederationPolicyArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_policy: Optional[pulumi.Input['ServicePrincipalFederationPolicyOidcPolicyArgs']] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a ServicePrincipalFederationPolicy resource.
        :param pulumi.Input[_builtins.str] description: Description of the federation policy
        :param pulumi.Input[_builtins.str] policy_id: (string) - The ID of the federation policy. Output only
        :param pulumi.Input[_builtins.int] service_principal_id: (integer) - The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if oidc_policy is not None:
            pulumi.set(__self__, "oidc_policy", oidc_policy)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if service_principal_id is not None:
            pulumi.set(__self__, "service_principal_id", service_principal_id)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the federation policy
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="oidcPolicy")
    def oidc_policy(self) -> Optional[pulumi.Input['ServicePrincipalFederationPolicyOidcPolicyArgs']]:
        return pulumi.get(self, "oidc_policy")

    @oidc_policy.setter
    def oidc_policy(self, value: Optional[pulumi.Input['ServicePrincipalFederationPolicyOidcPolicyArgs']]):
        pulumi.set(self, "oidc_policy", value)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The ID of the federation policy. Output only
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "service_principal_id", value)


@pulumi.input_type
class _ServicePrincipalFederationPolicyState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_policy: Optional[pulumi.Input['ServicePrincipalFederationPolicyOidcPolicyArgs']] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.int]] = None,
                 uid: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServicePrincipalFederationPolicy resources.
        :param pulumi.Input[_builtins.str] create_time: (string) - Creation time of the federation policy
        :param pulumi.Input[_builtins.str] description: Description of the federation policy
        :param pulumi.Input[_builtins.str] name: (string) - Resource name for the federation policy. Example values include
               `accounts/<account-id>/federationPolicies/my-federation-policy` for Account Federation Policies, and
               `accounts/<account-id>/servicePrincipals/<service-principal-id>/federationPolicies/my-federation-policy`
               for Service Principal Federation Policies. Typically an output parameter, which does not need to be
               specified in create or update requests. If specified in a request, must match the value in the
               request URL
        :param pulumi.Input[_builtins.str] policy_id: (string) - The ID of the federation policy. Output only
        :param pulumi.Input[_builtins.int] service_principal_id: (integer) - The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
        :param pulumi.Input[_builtins.str] uid: (string) - Unique, immutable id of the federation policy
        :param pulumi.Input[_builtins.str] update_time: (string) - Last update time of the federation policy
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if oidc_policy is not None:
            pulumi.set(__self__, "oidc_policy", oidc_policy)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if service_principal_id is not None:
            pulumi.set(__self__, "service_principal_id", service_principal_id)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Creation time of the federation policy
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the federation policy
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Resource name for the federation policy. Example values include
        `accounts/<account-id>/federationPolicies/my-federation-policy` for Account Federation Policies, and
        `accounts/<account-id>/servicePrincipals/<service-principal-id>/federationPolicies/my-federation-policy`
        for Service Principal Federation Policies. Typically an output parameter, which does not need to be
        specified in create or update requests. If specified in a request, must match the value in the
        request URL
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="oidcPolicy")
    def oidc_policy(self) -> Optional[pulumi.Input['ServicePrincipalFederationPolicyOidcPolicyArgs']]:
        return pulumi.get(self, "oidc_policy")

    @oidc_policy.setter
    def oidc_policy(self, value: Optional[pulumi.Input['ServicePrincipalFederationPolicyOidcPolicyArgs']]):
        pulumi.set(self, "oidc_policy", value)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The ID of the federation policy. Output only
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "service_principal_id", value)

    @_builtins.property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Unique, immutable id of the federation policy
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "uid", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Last update time of the federation policy
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("databricks:index/servicePrincipalFederationPolicy:ServicePrincipalFederationPolicy")
class ServicePrincipalFederationPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_policy: Optional[pulumi.Input[Union['ServicePrincipalFederationPolicyOidcPolicyArgs', 'ServicePrincipalFederationPolicyOidcPolicyArgsDict']]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Service principal federation policies allow automated workloads running outside of Databricks to access Databricks APIs without the need for Databricks secrets. Your application (workload) authenticates to Databricks as a Databricks service principal using tokens issued by the workload runtime, for example Github Actions.

        A service principal federation policy is associated with a service principal in your Databricks account, and specifies:
        * The identity provider (or issuer) from which the service principal can authenticate.
        * The workload identity (or subject) that is permitted to authenticate as the Databricks service principal.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.ServicePrincipalFederationPolicy("this",
            service_principal_id=1234,
            policy_id="my-policy",
            oidc_policy={
                "issuer": "https://myidp.example.com",
                "subject_claim": "sub",
                "subject": "subject-in-token-from-myidp",
            })
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "service_principal_id,policy_id"

          to = databricks_service_principal_federation_policy.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/servicePrincipalFederationPolicy:ServicePrincipalFederationPolicy this "service_principal_id,policy_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the federation policy
        :param pulumi.Input[_builtins.str] policy_id: (string) - The ID of the federation policy. Output only
        :param pulumi.Input[_builtins.int] service_principal_id: (integer) - The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ServicePrincipalFederationPolicyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Service principal federation policies allow automated workloads running outside of Databricks to access Databricks APIs without the need for Databricks secrets. Your application (workload) authenticates to Databricks as a Databricks service principal using tokens issued by the workload runtime, for example Github Actions.

        A service principal federation policy is associated with a service principal in your Databricks account, and specifies:
        * The identity provider (or issuer) from which the service principal can authenticate.
        * The workload identity (or subject) that is permitted to authenticate as the Databricks service principal.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.ServicePrincipalFederationPolicy("this",
            service_principal_id=1234,
            policy_id="my-policy",
            oidc_policy={
                "issuer": "https://myidp.example.com",
                "subject_claim": "sub",
                "subject": "subject-in-token-from-myidp",
            })
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "service_principal_id,policy_id"

          to = databricks_service_principal_federation_policy.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/servicePrincipalFederationPolicy:ServicePrincipalFederationPolicy this "service_principal_id,policy_id"
        ```

        :param str resource_name: The name of the resource.
        :param ServicePrincipalFederationPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServicePrincipalFederationPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 oidc_policy: Optional[pulumi.Input[Union['ServicePrincipalFederationPolicyOidcPolicyArgs', 'ServicePrincipalFederationPolicyOidcPolicyArgsDict']]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServicePrincipalFederationPolicyArgs.__new__(ServicePrincipalFederationPolicyArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["oidc_policy"] = oidc_policy
            __props__.__dict__["policy_id"] = policy_id
            __props__.__dict__["service_principal_id"] = service_principal_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["uid"] = None
            __props__.__dict__["update_time"] = None
        super(ServicePrincipalFederationPolicy, __self__).__init__(
            'databricks:index/servicePrincipalFederationPolicy:ServicePrincipalFederationPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            oidc_policy: Optional[pulumi.Input[Union['ServicePrincipalFederationPolicyOidcPolicyArgs', 'ServicePrincipalFederationPolicyOidcPolicyArgsDict']]] = None,
            policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            service_principal_id: Optional[pulumi.Input[_builtins.int]] = None,
            uid: Optional[pulumi.Input[_builtins.str]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None) -> 'ServicePrincipalFederationPolicy':
        """
        Get an existing ServicePrincipalFederationPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: (string) - Creation time of the federation policy
        :param pulumi.Input[_builtins.str] description: Description of the federation policy
        :param pulumi.Input[_builtins.str] name: (string) - Resource name for the federation policy. Example values include
               `accounts/<account-id>/federationPolicies/my-federation-policy` for Account Federation Policies, and
               `accounts/<account-id>/servicePrincipals/<service-principal-id>/federationPolicies/my-federation-policy`
               for Service Principal Federation Policies. Typically an output parameter, which does not need to be
               specified in create or update requests. If specified in a request, must match the value in the
               request URL
        :param pulumi.Input[_builtins.str] policy_id: (string) - The ID of the federation policy. Output only
        :param pulumi.Input[_builtins.int] service_principal_id: (integer) - The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
        :param pulumi.Input[_builtins.str] uid: (string) - Unique, immutable id of the federation policy
        :param pulumi.Input[_builtins.str] update_time: (string) - Last update time of the federation policy
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServicePrincipalFederationPolicyState.__new__(_ServicePrincipalFederationPolicyState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["oidc_policy"] = oidc_policy
        __props__.__dict__["policy_id"] = policy_id
        __props__.__dict__["service_principal_id"] = service_principal_id
        __props__.__dict__["uid"] = uid
        __props__.__dict__["update_time"] = update_time
        return ServicePrincipalFederationPolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Creation time of the federation policy
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the federation policy
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Resource name for the federation policy. Example values include
        `accounts/<account-id>/federationPolicies/my-federation-policy` for Account Federation Policies, and
        `accounts/<account-id>/servicePrincipals/<service-principal-id>/federationPolicies/my-federation-policy`
        for Service Principal Federation Policies. Typically an output parameter, which does not need to be
        specified in create or update requests. If specified in a request, must match the value in the
        request URL
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="oidcPolicy")
    def oidc_policy(self) -> pulumi.Output[Optional['outputs.ServicePrincipalFederationPolicyOidcPolicy']]:
        return pulumi.get(self, "oidc_policy")

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The ID of the federation policy. Output only
        """
        return pulumi.get(self, "policy_id")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
        """
        return pulumi.get(self, "service_principal_id")

    @_builtins.property
    @pulumi.getter
    def uid(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Unique, immutable id of the federation policy
        """
        return pulumi.get(self, "uid")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Last update time of the federation policy
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAccountSettingV2Result',
    'AwaitableGetAccountSettingV2Result',
    'get_account_setting_v2',
    'get_account_setting_v2_output',
]

@pulumi.output_type
class GetAccountSettingV2Result:
    """
    A collection of values returned by getAccountSettingV2.
    """
    def __init__(__self__, aibi_dashboard_embedding_access_policy=None, aibi_dashboard_embedding_approved_domains=None, automatic_cluster_update_workspace=None, boolean_val=None, effective_aibi_dashboard_embedding_access_policy=None, effective_aibi_dashboard_embedding_approved_domains=None, effective_automatic_cluster_update_workspace=None, effective_boolean_val=None, effective_integer_val=None, effective_personal_compute=None, effective_restrict_workspace_admins=None, effective_string_val=None, id=None, integer_val=None, name=None, personal_compute=None, restrict_workspace_admins=None, string_val=None):
        if aibi_dashboard_embedding_access_policy and not isinstance(aibi_dashboard_embedding_access_policy, dict):
            raise TypeError("Expected argument 'aibi_dashboard_embedding_access_policy' to be a dict")
        pulumi.set(__self__, "aibi_dashboard_embedding_access_policy", aibi_dashboard_embedding_access_policy)
        if aibi_dashboard_embedding_approved_domains and not isinstance(aibi_dashboard_embedding_approved_domains, dict):
            raise TypeError("Expected argument 'aibi_dashboard_embedding_approved_domains' to be a dict")
        pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if automatic_cluster_update_workspace and not isinstance(automatic_cluster_update_workspace, dict):
            raise TypeError("Expected argument 'automatic_cluster_update_workspace' to be a dict")
        pulumi.set(__self__, "automatic_cluster_update_workspace", automatic_cluster_update_workspace)
        if boolean_val and not isinstance(boolean_val, dict):
            raise TypeError("Expected argument 'boolean_val' to be a dict")
        pulumi.set(__self__, "boolean_val", boolean_val)
        if effective_aibi_dashboard_embedding_access_policy and not isinstance(effective_aibi_dashboard_embedding_access_policy, dict):
            raise TypeError("Expected argument 'effective_aibi_dashboard_embedding_access_policy' to be a dict")
        pulumi.set(__self__, "effective_aibi_dashboard_embedding_access_policy", effective_aibi_dashboard_embedding_access_policy)
        if effective_aibi_dashboard_embedding_approved_domains and not isinstance(effective_aibi_dashboard_embedding_approved_domains, dict):
            raise TypeError("Expected argument 'effective_aibi_dashboard_embedding_approved_domains' to be a dict")
        pulumi.set(__self__, "effective_aibi_dashboard_embedding_approved_domains", effective_aibi_dashboard_embedding_approved_domains)
        if effective_automatic_cluster_update_workspace and not isinstance(effective_automatic_cluster_update_workspace, dict):
            raise TypeError("Expected argument 'effective_automatic_cluster_update_workspace' to be a dict")
        pulumi.set(__self__, "effective_automatic_cluster_update_workspace", effective_automatic_cluster_update_workspace)
        if effective_boolean_val and not isinstance(effective_boolean_val, dict):
            raise TypeError("Expected argument 'effective_boolean_val' to be a dict")
        pulumi.set(__self__, "effective_boolean_val", effective_boolean_val)
        if effective_integer_val and not isinstance(effective_integer_val, dict):
            raise TypeError("Expected argument 'effective_integer_val' to be a dict")
        pulumi.set(__self__, "effective_integer_val", effective_integer_val)
        if effective_personal_compute and not isinstance(effective_personal_compute, dict):
            raise TypeError("Expected argument 'effective_personal_compute' to be a dict")
        pulumi.set(__self__, "effective_personal_compute", effective_personal_compute)
        if effective_restrict_workspace_admins and not isinstance(effective_restrict_workspace_admins, dict):
            raise TypeError("Expected argument 'effective_restrict_workspace_admins' to be a dict")
        pulumi.set(__self__, "effective_restrict_workspace_admins", effective_restrict_workspace_admins)
        if effective_string_val and not isinstance(effective_string_val, dict):
            raise TypeError("Expected argument 'effective_string_val' to be a dict")
        pulumi.set(__self__, "effective_string_val", effective_string_val)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if integer_val and not isinstance(integer_val, dict):
            raise TypeError("Expected argument 'integer_val' to be a dict")
        pulumi.set(__self__, "integer_val", integer_val)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if personal_compute and not isinstance(personal_compute, dict):
            raise TypeError("Expected argument 'personal_compute' to be a dict")
        pulumi.set(__self__, "personal_compute", personal_compute)
        if restrict_workspace_admins and not isinstance(restrict_workspace_admins, dict):
            raise TypeError("Expected argument 'restrict_workspace_admins' to be a dict")
        pulumi.set(__self__, "restrict_workspace_admins", restrict_workspace_admins)
        if string_val and not isinstance(string_val, dict):
            raise TypeError("Expected argument 'string_val' to be a dict")
        pulumi.set(__self__, "string_val", string_val)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingAccessPolicy")
    def aibi_dashboard_embedding_access_policy(self) -> 'outputs.GetAccountSettingV2AibiDashboardEmbeddingAccessPolicyResult':
        """
        (AibiDashboardEmbeddingAccessPolicy)
        """
        return pulumi.get(self, "aibi_dashboard_embedding_access_policy")

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> 'outputs.GetAccountSettingV2AibiDashboardEmbeddingApprovedDomainsResult':
        """
        (AibiDashboardEmbeddingApprovedDomains)
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter(name="automaticClusterUpdateWorkspace")
    def automatic_cluster_update_workspace(self) -> 'outputs.GetAccountSettingV2AutomaticClusterUpdateWorkspaceResult':
        """
        (ClusterAutoRestartMessage)
        """
        return pulumi.get(self, "automatic_cluster_update_workspace")

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> 'outputs.GetAccountSettingV2BooleanValResult':
        """
        (BooleanMessage)
        """
        return pulumi.get(self, "boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingAccessPolicy")
    def effective_aibi_dashboard_embedding_access_policy(self) -> 'outputs.GetAccountSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyResult':
        """
        (AibiDashboardEmbeddingAccessPolicy)
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_access_policy")

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingApprovedDomains")
    def effective_aibi_dashboard_embedding_approved_domains(self) -> 'outputs.GetAccountSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsResult':
        """
        (AibiDashboardEmbeddingApprovedDomains)
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter(name="effectiveAutomaticClusterUpdateWorkspace")
    def effective_automatic_cluster_update_workspace(self) -> 'outputs.GetAccountSettingV2EffectiveAutomaticClusterUpdateWorkspaceResult':
        """
        (ClusterAutoRestartMessage)
        """
        return pulumi.get(self, "effective_automatic_cluster_update_workspace")

    @_builtins.property
    @pulumi.getter(name="effectiveBooleanVal")
    def effective_boolean_val(self) -> 'outputs.GetAccountSettingV2EffectiveBooleanValResult':
        """
        (BooleanMessage)
        """
        return pulumi.get(self, "effective_boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveIntegerVal")
    def effective_integer_val(self) -> 'outputs.GetAccountSettingV2EffectiveIntegerValResult':
        """
        (IntegerMessage)
        """
        return pulumi.get(self, "effective_integer_val")

    @_builtins.property
    @pulumi.getter(name="effectivePersonalCompute")
    def effective_personal_compute(self) -> 'outputs.GetAccountSettingV2EffectivePersonalComputeResult':
        """
        (PersonalComputeMessage)
        """
        return pulumi.get(self, "effective_personal_compute")

    @_builtins.property
    @pulumi.getter(name="effectiveRestrictWorkspaceAdmins")
    def effective_restrict_workspace_admins(self) -> 'outputs.GetAccountSettingV2EffectiveRestrictWorkspaceAdminsResult':
        """
        (RestrictWorkspaceAdminsMessage)
        """
        return pulumi.get(self, "effective_restrict_workspace_admins")

    @_builtins.property
    @pulumi.getter(name="effectiveStringVal")
    def effective_string_val(self) -> 'outputs.GetAccountSettingV2EffectiveStringValResult':
        """
        (StringMessage)
        """
        return pulumi.get(self, "effective_string_val")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="integerVal")
    def integer_val(self) -> 'outputs.GetAccountSettingV2IntegerValResult':
        """
        (IntegerMessage)
        """
        return pulumi.get(self, "integer_val")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Name of the setting
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="personalCompute")
    def personal_compute(self) -> 'outputs.GetAccountSettingV2PersonalComputeResult':
        """
        (PersonalComputeMessage)
        """
        return pulumi.get(self, "personal_compute")

    @_builtins.property
    @pulumi.getter(name="restrictWorkspaceAdmins")
    def restrict_workspace_admins(self) -> 'outputs.GetAccountSettingV2RestrictWorkspaceAdminsResult':
        """
        (RestrictWorkspaceAdminsMessage)
        """
        return pulumi.get(self, "restrict_workspace_admins")

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> 'outputs.GetAccountSettingV2StringValResult':
        """
        (StringMessage)
        """
        return pulumi.get(self, "string_val")


class AwaitableGetAccountSettingV2Result(GetAccountSettingV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountSettingV2Result(
            aibi_dashboard_embedding_access_policy=self.aibi_dashboard_embedding_access_policy,
            aibi_dashboard_embedding_approved_domains=self.aibi_dashboard_embedding_approved_domains,
            automatic_cluster_update_workspace=self.automatic_cluster_update_workspace,
            boolean_val=self.boolean_val,
            effective_aibi_dashboard_embedding_access_policy=self.effective_aibi_dashboard_embedding_access_policy,
            effective_aibi_dashboard_embedding_approved_domains=self.effective_aibi_dashboard_embedding_approved_domains,
            effective_automatic_cluster_update_workspace=self.effective_automatic_cluster_update_workspace,
            effective_boolean_val=self.effective_boolean_val,
            effective_integer_val=self.effective_integer_val,
            effective_personal_compute=self.effective_personal_compute,
            effective_restrict_workspace_admins=self.effective_restrict_workspace_admins,
            effective_string_val=self.effective_string_val,
            id=self.id,
            integer_val=self.integer_val,
            name=self.name,
            personal_compute=self.personal_compute,
            restrict_workspace_admins=self.restrict_workspace_admins,
            string_val=self.string_val)


def get_account_setting_v2(name: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountSettingV2Result:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single account setting.

    ## Example Usage

    Referring to a setting by id


    :param _builtins.str name: Name of the setting
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getAccountSettingV2:getAccountSettingV2', __args__, opts=opts, typ=GetAccountSettingV2Result).value

    return AwaitableGetAccountSettingV2Result(
        aibi_dashboard_embedding_access_policy=pulumi.get(__ret__, 'aibi_dashboard_embedding_access_policy'),
        aibi_dashboard_embedding_approved_domains=pulumi.get(__ret__, 'aibi_dashboard_embedding_approved_domains'),
        automatic_cluster_update_workspace=pulumi.get(__ret__, 'automatic_cluster_update_workspace'),
        boolean_val=pulumi.get(__ret__, 'boolean_val'),
        effective_aibi_dashboard_embedding_access_policy=pulumi.get(__ret__, 'effective_aibi_dashboard_embedding_access_policy'),
        effective_aibi_dashboard_embedding_approved_domains=pulumi.get(__ret__, 'effective_aibi_dashboard_embedding_approved_domains'),
        effective_automatic_cluster_update_workspace=pulumi.get(__ret__, 'effective_automatic_cluster_update_workspace'),
        effective_boolean_val=pulumi.get(__ret__, 'effective_boolean_val'),
        effective_integer_val=pulumi.get(__ret__, 'effective_integer_val'),
        effective_personal_compute=pulumi.get(__ret__, 'effective_personal_compute'),
        effective_restrict_workspace_admins=pulumi.get(__ret__, 'effective_restrict_workspace_admins'),
        effective_string_val=pulumi.get(__ret__, 'effective_string_val'),
        id=pulumi.get(__ret__, 'id'),
        integer_val=pulumi.get(__ret__, 'integer_val'),
        name=pulumi.get(__ret__, 'name'),
        personal_compute=pulumi.get(__ret__, 'personal_compute'),
        restrict_workspace_admins=pulumi.get(__ret__, 'restrict_workspace_admins'),
        string_val=pulumi.get(__ret__, 'string_val'))
def get_account_setting_v2_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountSettingV2Result]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single account setting.

    ## Example Usage

    Referring to a setting by id


    :param _builtins.str name: Name of the setting
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getAccountSettingV2:getAccountSettingV2', __args__, opts=opts, typ=GetAccountSettingV2Result)
    return __ret__.apply(lambda __response__: GetAccountSettingV2Result(
        aibi_dashboard_embedding_access_policy=pulumi.get(__response__, 'aibi_dashboard_embedding_access_policy'),
        aibi_dashboard_embedding_approved_domains=pulumi.get(__response__, 'aibi_dashboard_embedding_approved_domains'),
        automatic_cluster_update_workspace=pulumi.get(__response__, 'automatic_cluster_update_workspace'),
        boolean_val=pulumi.get(__response__, 'boolean_val'),
        effective_aibi_dashboard_embedding_access_policy=pulumi.get(__response__, 'effective_aibi_dashboard_embedding_access_policy'),
        effective_aibi_dashboard_embedding_approved_domains=pulumi.get(__response__, 'effective_aibi_dashboard_embedding_approved_domains'),
        effective_automatic_cluster_update_workspace=pulumi.get(__response__, 'effective_automatic_cluster_update_workspace'),
        effective_boolean_val=pulumi.get(__response__, 'effective_boolean_val'),
        effective_integer_val=pulumi.get(__response__, 'effective_integer_val'),
        effective_personal_compute=pulumi.get(__response__, 'effective_personal_compute'),
        effective_restrict_workspace_admins=pulumi.get(__response__, 'effective_restrict_workspace_admins'),
        effective_string_val=pulumi.get(__response__, 'effective_string_val'),
        id=pulumi.get(__response__, 'id'),
        integer_val=pulumi.get(__response__, 'integer_val'),
        name=pulumi.get(__response__, 'name'),
        personal_compute=pulumi.get(__response__, 'personal_compute'),
        restrict_workspace_admins=pulumi.get(__response__, 'restrict_workspace_admins'),
        string_val=pulumi.get(__response__, 'string_val')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetJobsResult',
    'AwaitableGetJobsResult',
    'get_jobs',
    'get_jobs_output',
]

@pulumi.output_type
class GetJobsResult:
    """
    A collection of values returned by getJobs.
    """
    def __init__(__self__, id=None, ids=None, job_name_contains=None, key=None, provider_config=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, dict):
            raise TypeError("Expected argument 'ids' to be a dict")
        pulumi.set(__self__, "ids", ids)
        if job_name_contains and not isinstance(job_name_contains, str):
            raise TypeError("Expected argument 'job_name_contains' to be a str")
        pulumi.set(__self__, "job_name_contains", job_name_contains)
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ids(self) -> Mapping[str, _builtins.str]:
        """
        map of Job names to ids
        """
        return pulumi.get(self, "ids")

    @_builtins.property
    @pulumi.getter(name="jobNameContains")
    def job_name_contains(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "job_name_contains")

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetJobsProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetJobsResult(GetJobsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetJobsResult(
            id=self.id,
            ids=self.ids,
            job_name_contains=self.job_name_contains,
            key=self.key,
            provider_config=self.provider_config)


def get_jobs(ids: Optional[Mapping[str, _builtins.str]] = None,
             job_name_contains: Optional[_builtins.str] = None,
             key: Optional[_builtins.str] = None,
             provider_config: Optional[Union['GetJobsProviderConfigArgs', 'GetJobsProviderConfigArgsDict']] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetJobsResult:
    """
    Retrieves a list of Job ids, that were created by Pulumi or manually, so that special handling could be applied.

    > This data source can only be used with a workspace-level provider!

    > By default, this data resource will error in case of jobs with duplicate names. To support duplicate names, set `key = "id"` to map jobs by ID.

    ## Example Usage

    Granting view Permissions to all Job within the workspace:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_jobs()
    everyone_can_view_all_jobs = []
    for range in [{"key": k, "value": v} for [k, v] in enumerate(this.ids)]:
        everyone_can_view_all_jobs.append(databricks.Permissions(f"everyone_can_view_all_jobs-{range['key']}",
            job_id=range["value"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_VIEW",
            }]))
    ```

    Getting ID of specific Job by name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_jobs(job_name_contains="test")
    pulumi.export("x", f"ID of `x` job is {this.ids['x']}")
    ```

    Getting IDs of Job mapped by ID, allowing duplicate job names:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_jobs(key="id")
    everyone_can_view_all_jobs = []
    for range in [{"key": k, "value": v} for [k, v] in enumerate(this.ids)]:
        everyone_can_view_all_jobs.append(databricks.Permissions(f"everyone_can_view_all_jobs-{range['key']}",
            job_id=range["value"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_VIEW",
            }]))
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code in a databricks_cluster.


    :param Mapping[str, _builtins.str] ids: map of Job names to ids
    :param _builtins.str job_name_contains: Only return Job ids that match the given name string (case-insensitive).
    :param _builtins.str key: Attribute to use for keys in the returned map of Job ids by. Possible values are `name` (default) or `id`. Setting to `id` uses the job ID as the map key, allowing duplicate job names.
    :param Union['GetJobsProviderConfigArgs', 'GetJobsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['jobNameContains'] = job_name_contains
    __args__['key'] = key
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getJobs:getJobs', __args__, opts=opts, typ=GetJobsResult).value

    return AwaitableGetJobsResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        job_name_contains=pulumi.get(__ret__, 'job_name_contains'),
        key=pulumi.get(__ret__, 'key'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_jobs_output(ids: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                    job_name_contains: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    key: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    provider_config: Optional[pulumi.Input[Optional[Union['GetJobsProviderConfigArgs', 'GetJobsProviderConfigArgsDict']]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetJobsResult]:
    """
    Retrieves a list of Job ids, that were created by Pulumi or manually, so that special handling could be applied.

    > This data source can only be used with a workspace-level provider!

    > By default, this data resource will error in case of jobs with duplicate names. To support duplicate names, set `key = "id"` to map jobs by ID.

    ## Example Usage

    Granting view Permissions to all Job within the workspace:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_jobs()
    everyone_can_view_all_jobs = []
    for range in [{"key": k, "value": v} for [k, v] in enumerate(this.ids)]:
        everyone_can_view_all_jobs.append(databricks.Permissions(f"everyone_can_view_all_jobs-{range['key']}",
            job_id=range["value"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_VIEW",
            }]))
    ```

    Getting ID of specific Job by name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_jobs(job_name_contains="test")
    pulumi.export("x", f"ID of `x` job is {this.ids['x']}")
    ```

    Getting IDs of Job mapped by ID, allowing duplicate job names:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_jobs(key="id")
    everyone_can_view_all_jobs = []
    for range in [{"key": k, "value": v} for [k, v] in enumerate(this.ids)]:
        everyone_can_view_all_jobs.append(databricks.Permissions(f"everyone_can_view_all_jobs-{range['key']}",
            job_id=range["value"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_VIEW",
            }]))
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code in a databricks_cluster.


    :param Mapping[str, _builtins.str] ids: map of Job names to ids
    :param _builtins.str job_name_contains: Only return Job ids that match the given name string (case-insensitive).
    :param _builtins.str key: Attribute to use for keys in the returned map of Job ids by. Possible values are `name` (default) or `id`. Setting to `id` uses the job ID as the map key, allowing duplicate job names.
    :param Union['GetJobsProviderConfigArgs', 'GetJobsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['jobNameContains'] = job_name_contains
    __args__['key'] = key
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getJobs:getJobs', __args__, opts=opts, typ=GetJobsResult)
    return __ret__.apply(lambda __response__: GetJobsResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        job_name_contains=pulumi.get(__response__, 'job_name_contains'),
        key=pulumi.get(__response__, 'key'),
        provider_config=pulumi.get(__response__, 'provider_config')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['OnlineStoreArgs', 'OnlineStore']

@pulumi.input_type
class OnlineStoreArgs:
    def __init__(__self__, *,
                 capacity: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 read_replica_count: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a OnlineStore resource.
        :param pulumi.Input[_builtins.str] capacity: The capacity of the online store. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[_builtins.str] name: The name of the online store. This is the unique identifier for the online store
        :param pulumi.Input[_builtins.int] read_replica_count: The number of read replicas for the online store. Defaults to 0
        """
        pulumi.set(__self__, "capacity", capacity)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if read_replica_count is not None:
            pulumi.set(__self__, "read_replica_count", read_replica_count)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> pulumi.Input[_builtins.str]:
        """
        The capacity of the online store. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "capacity", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the online store. This is the unique identifier for the online store
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="readReplicaCount")
    def read_replica_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of read replicas for the online store. Defaults to 0
        """
        return pulumi.get(self, "read_replica_count")

    @read_replica_count.setter
    def read_replica_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "read_replica_count", value)


@pulumi.input_type
class _OnlineStoreState:
    def __init__(__self__, *,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 creation_time: Optional[pulumi.Input[_builtins.str]] = None,
                 creator: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 read_replica_count: Optional[pulumi.Input[_builtins.int]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering OnlineStore resources.
        :param pulumi.Input[_builtins.str] capacity: The capacity of the online store. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[_builtins.str] creation_time: (string) - The timestamp when the online store was created
        :param pulumi.Input[_builtins.str] creator: (string) - The email of the creator of the online store
        :param pulumi.Input[_builtins.str] name: The name of the online store. This is the unique identifier for the online store
        :param pulumi.Input[_builtins.int] read_replica_count: The number of read replicas for the online store. Defaults to 0
        :param pulumi.Input[_builtins.str] state: (string) - The current state of the online store. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        """
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if creator is not None:
            pulumi.set(__self__, "creator", creator)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if read_replica_count is not None:
            pulumi.set(__self__, "read_replica_count", read_replica_count)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The capacity of the online store. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "capacity", value)

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The timestamp when the online store was created
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creation_time", value)

    @_builtins.property
    @pulumi.getter
    def creator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The email of the creator of the online store
        """
        return pulumi.get(self, "creator")

    @creator.setter
    def creator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the online store. This is the unique identifier for the online store
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="readReplicaCount")
    def read_replica_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of read replicas for the online store. Defaults to 0
        """
        return pulumi.get(self, "read_replica_count")

    @read_replica_count.setter
    def read_replica_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "read_replica_count", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The current state of the online store. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)


@pulumi.type_token("databricks:index/onlineStore:OnlineStore")
class OnlineStore(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 read_replica_count: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_online_store.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/onlineStore:OnlineStore this "name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] capacity: The capacity of the online store. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[_builtins.str] name: The name of the online store. This is the unique identifier for the online store
        :param pulumi.Input[_builtins.int] read_replica_count: The number of read replicas for the online store. Defaults to 0
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OnlineStoreArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "name"

          to = databricks_online_store.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/onlineStore:OnlineStore this "name"
        ```

        :param str resource_name: The name of the resource.
        :param OnlineStoreArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OnlineStoreArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 read_replica_count: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OnlineStoreArgs.__new__(OnlineStoreArgs)

            if capacity is None and not opts.urn:
                raise TypeError("Missing required property 'capacity'")
            __props__.__dict__["capacity"] = capacity
            __props__.__dict__["name"] = name
            __props__.__dict__["read_replica_count"] = read_replica_count
            __props__.__dict__["creation_time"] = None
            __props__.__dict__["creator"] = None
            __props__.__dict__["state"] = None
        super(OnlineStore, __self__).__init__(
            'databricks:index/onlineStore:OnlineStore',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            capacity: Optional[pulumi.Input[_builtins.str]] = None,
            creation_time: Optional[pulumi.Input[_builtins.str]] = None,
            creator: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            read_replica_count: Optional[pulumi.Input[_builtins.int]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None) -> 'OnlineStore':
        """
        Get an existing OnlineStore resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] capacity: The capacity of the online store. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[_builtins.str] creation_time: (string) - The timestamp when the online store was created
        :param pulumi.Input[_builtins.str] creator: (string) - The email of the creator of the online store
        :param pulumi.Input[_builtins.str] name: The name of the online store. This is the unique identifier for the online store
        :param pulumi.Input[_builtins.int] read_replica_count: The number of read replicas for the online store. Defaults to 0
        :param pulumi.Input[_builtins.str] state: (string) - The current state of the online store. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OnlineStoreState.__new__(_OnlineStoreState)

        __props__.__dict__["capacity"] = capacity
        __props__.__dict__["creation_time"] = creation_time
        __props__.__dict__["creator"] = creator
        __props__.__dict__["name"] = name
        __props__.__dict__["read_replica_count"] = read_replica_count
        __props__.__dict__["state"] = state
        return OnlineStore(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> pulumi.Output[_builtins.str]:
        """
        The capacity of the online store. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The timestamp when the online store was created
        """
        return pulumi.get(self, "creation_time")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The email of the creator of the online store
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the online store. This is the unique identifier for the online store
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="readReplicaCount")
    def read_replica_count(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of read replicas for the online store. Defaults to 0
        """
        return pulumi.get(self, "read_replica_count")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The current state of the online store. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetWorkspaceNetworkOptionResult',
    'AwaitableGetWorkspaceNetworkOptionResult',
    'get_workspace_network_option',
    'get_workspace_network_option_output',
]

@pulumi.output_type
class GetWorkspaceNetworkOptionResult:
    """
    A collection of values returned by getWorkspaceNetworkOption.
    """
    def __init__(__self__, id=None, network_policy_id=None, workspace_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if network_policy_id and not isinstance(network_policy_id, str):
            raise TypeError("Expected argument 'network_policy_id' to be a str")
        pulumi.set(__self__, "network_policy_id", network_policy_id)
        if workspace_id and not isinstance(workspace_id, str):
            raise TypeError("Expected argument 'workspace_id' to be a str")
        pulumi.set(__self__, "workspace_id", workspace_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="networkPolicyId")
    def network_policy_id(self) -> _builtins.str:
        """
        (string) - The network policy ID to apply to the workspace. This controls the network access rules
        for all serverless compute resources in the workspace. Each workspace can only be
        linked to one policy at a time. If no policy is explicitly assigned,
        the workspace will use 'default-policy'
        """
        return pulumi.get(self, "network_policy_id")

    @_builtins.property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> _builtins.str:
        """
        (integer) - The workspace ID
        """
        return pulumi.get(self, "workspace_id")


class AwaitableGetWorkspaceNetworkOptionResult(GetWorkspaceNetworkOptionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWorkspaceNetworkOptionResult(
            id=self.id,
            network_policy_id=self.network_policy_id,
            workspace_id=self.workspace_id)


def get_workspace_network_option(workspace_id: Optional[_builtins.str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWorkspaceNetworkOptionResult:
    """
    [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single workspace network option.

    > **Note** This data source can only be used with an account-level provider!

    ## Example Usage

    Referring to a network policy by id:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_workspace_network_option(workspace_id="9999999999999999")
    ```


    :param _builtins.str workspace_id: The workspace ID
    """
    __args__ = dict()
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getWorkspaceNetworkOption:getWorkspaceNetworkOption', __args__, opts=opts, typ=GetWorkspaceNetworkOptionResult).value

    return AwaitableGetWorkspaceNetworkOptionResult(
        id=pulumi.get(__ret__, 'id'),
        network_policy_id=pulumi.get(__ret__, 'network_policy_id'),
        workspace_id=pulumi.get(__ret__, 'workspace_id'))
def get_workspace_network_option_output(workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetWorkspaceNetworkOptionResult]:
    """
    [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single workspace network option.

    > **Note** This data source can only be used with an account-level provider!

    ## Example Usage

    Referring to a network policy by id:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_workspace_network_option(workspace_id="9999999999999999")
    ```


    :param _builtins.str workspace_id: The workspace ID
    """
    __args__ = dict()
    __args__['workspaceId'] = workspace_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getWorkspaceNetworkOption:getWorkspaceNetworkOption', __args__, opts=opts, typ=GetWorkspaceNetworkOptionResult)
    return __ret__.apply(lambda __response__: GetWorkspaceNetworkOptionResult(
        id=pulumi.get(__response__, 'id'),
        network_policy_id=pulumi.get(__response__, 'network_policy_id'),
        workspace_id=pulumi.get(__response__, 'workspace_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetMwsWorkspacesResult',
    'AwaitableGetMwsWorkspacesResult',
    'get_mws_workspaces',
    'get_mws_workspaces_output',
]

@pulumi.output_type
class GetMwsWorkspacesResult:
    """
    A collection of values returned by getMwsWorkspaces.
    """
    def __init__(__self__, id=None, ids=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, dict):
            raise TypeError("Expected argument 'ids' to be a dict")
        pulumi.set(__self__, "ids", ids)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ids(self) -> Mapping[str, _builtins.str]:
        """
        name-to-id map for all of the workspaces in the account
        """
        return pulumi.get(self, "ids")


class AwaitableGetMwsWorkspacesResult(GetMwsWorkspacesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMwsWorkspacesResult(
            id=self.id,
            ids=self.ids)


def get_mws_workspaces(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMwsWorkspacesResult:
    """
    Lists all MwsWorkspaces in Databricks Account.

    > This data source can only be used with an account-level provider!

    ## Example Usage

    Listing all workspaces in

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_mws_workspaces()
    pulumi.export("allMwsWorkspaces", all.ids)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * MwsWorkspaces to manage Databricks Workspaces on AWS and GCP.
    * MetastoreAssignment to assign Metastore to MwsWorkspaces or azurerm_databricks_workspace
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getMwsWorkspaces:getMwsWorkspaces', __args__, opts=opts, typ=GetMwsWorkspacesResult).value

    return AwaitableGetMwsWorkspacesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'))
def get_mws_workspaces_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMwsWorkspacesResult]:
    """
    Lists all MwsWorkspaces in Databricks Account.

    > This data source can only be used with an account-level provider!

    ## Example Usage

    Listing all workspaces in

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_mws_workspaces()
    pulumi.export("allMwsWorkspaces", all.ids)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * MwsWorkspaces to manage Databricks Workspaces on AWS and GCP.
    * MetastoreAssignment to assign Metastore to MwsWorkspaces or azurerm_databricks_workspace
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getMwsWorkspaces:getMwsWorkspaces', __args__, opts=opts, typ=GetMwsWorkspacesResult)
    return __ret__.apply(lambda __response__: GetMwsWorkspacesResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetFeatureEngineeringMaterializedFeaturesResult',
    'AwaitableGetFeatureEngineeringMaterializedFeaturesResult',
    'get_feature_engineering_materialized_features',
    'get_feature_engineering_materialized_features_output',
]

@pulumi.output_type
class GetFeatureEngineeringMaterializedFeaturesResult:
    """
    A collection of values returned by getFeatureEngineeringMaterializedFeatures.
    """
    def __init__(__self__, feature_name=None, id=None, materialized_features=None, page_size=None):
        if feature_name and not isinstance(feature_name, str):
            raise TypeError("Expected argument 'feature_name' to be a str")
        pulumi.set(__self__, "feature_name", feature_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if materialized_features and not isinstance(materialized_features, list):
            raise TypeError("Expected argument 'materialized_features' to be a list")
        pulumi.set(__self__, "materialized_features", materialized_features)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)

    @_builtins.property
    @pulumi.getter(name="featureName")
    def feature_name(self) -> Optional[_builtins.str]:
        """
        (string) - The full name of the feature in Unity Catalog
        """
        return pulumi.get(self, "feature_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="materializedFeatures")
    def materialized_features(self) -> Sequence['outputs.GetFeatureEngineeringMaterializedFeaturesMaterializedFeatureResult']:
        return pulumi.get(self, "materialized_features")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")


class AwaitableGetFeatureEngineeringMaterializedFeaturesResult(GetFeatureEngineeringMaterializedFeaturesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFeatureEngineeringMaterializedFeaturesResult(
            feature_name=self.feature_name,
            id=self.id,
            materialized_features=self.materialized_features,
            page_size=self.page_size)


def get_feature_engineering_materialized_features(feature_name: Optional[_builtins.str] = None,
                                                  page_size: Optional[_builtins.int] = None,
                                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFeatureEngineeringMaterializedFeaturesResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str feature_name: Filter by feature name. If specified, only materialized features materialized from this feature will be returned
    :param _builtins.int page_size: The maximum number of results to return. Defaults to 100 if not specified. Cannot be greater than 1000
    """
    __args__ = dict()
    __args__['featureName'] = feature_name
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getFeatureEngineeringMaterializedFeatures:getFeatureEngineeringMaterializedFeatures', __args__, opts=opts, typ=GetFeatureEngineeringMaterializedFeaturesResult).value

    return AwaitableGetFeatureEngineeringMaterializedFeaturesResult(
        feature_name=pulumi.get(__ret__, 'feature_name'),
        id=pulumi.get(__ret__, 'id'),
        materialized_features=pulumi.get(__ret__, 'materialized_features'),
        page_size=pulumi.get(__ret__, 'page_size'))
def get_feature_engineering_materialized_features_output(feature_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                         page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFeatureEngineeringMaterializedFeaturesResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str feature_name: Filter by feature name. If specified, only materialized features materialized from this feature will be returned
    :param _builtins.int page_size: The maximum number of results to return. Defaults to 100 if not specified. Cannot be greater than 1000
    """
    __args__ = dict()
    __args__['featureName'] = feature_name
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getFeatureEngineeringMaterializedFeatures:getFeatureEngineeringMaterializedFeatures', __args__, opts=opts, typ=GetFeatureEngineeringMaterializedFeaturesResult)
    return __ret__.apply(lambda __response__: GetFeatureEngineeringMaterializedFeaturesResult(
        feature_name=pulumi.get(__response__, 'feature_name'),
        id=pulumi.get(__response__, 'id'),
        materialized_features=pulumi.get(__response__, 'materialized_features'),
        page_size=pulumi.get(__response__, 'page_size')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDatabaseDatabaseCatalogResult',
    'AwaitableGetDatabaseDatabaseCatalogResult',
    'get_database_database_catalog',
    'get_database_database_catalog_output',
]

@pulumi.output_type
class GetDatabaseDatabaseCatalogResult:
    """
    A collection of values returned by getDatabaseDatabaseCatalog.
    """
    def __init__(__self__, create_database_if_not_exists=None, database_instance_name=None, database_name=None, id=None, name=None, uid=None):
        if create_database_if_not_exists and not isinstance(create_database_if_not_exists, bool):
            raise TypeError("Expected argument 'create_database_if_not_exists' to be a bool")
        pulumi.set(__self__, "create_database_if_not_exists", create_database_if_not_exists)
        if database_instance_name and not isinstance(database_instance_name, str):
            raise TypeError("Expected argument 'database_instance_name' to be a str")
        pulumi.set(__self__, "database_instance_name", database_instance_name)
        if database_name and not isinstance(database_name, str):
            raise TypeError("Expected argument 'database_name' to be a str")
        pulumi.set(__self__, "database_name", database_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if uid and not isinstance(uid, str):
            raise TypeError("Expected argument 'uid' to be a str")
        pulumi.set(__self__, "uid", uid)

    @_builtins.property
    @pulumi.getter(name="createDatabaseIfNotExists")
    def create_database_if_not_exists(self) -> _builtins.bool:
        """
        (boolean)
        """
        return pulumi.get(self, "create_database_if_not_exists")

    @_builtins.property
    @pulumi.getter(name="databaseInstanceName")
    def database_instance_name(self) -> _builtins.str:
        """
        (string) - The name of the DatabaseInstance housing the database
        """
        return pulumi.get(self, "database_instance_name")

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> _builtins.str:
        """
        (string) - The name of the database (in a instance) associated with the catalog
        """
        return pulumi.get(self, "database_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - The name of the catalog in UC
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def uid(self) -> _builtins.str:
        """
        (string)
        """
        return pulumi.get(self, "uid")


class AwaitableGetDatabaseDatabaseCatalogResult(GetDatabaseDatabaseCatalogResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseDatabaseCatalogResult(
            create_database_if_not_exists=self.create_database_if_not_exists,
            database_instance_name=self.database_instance_name,
            database_name=self.database_name,
            id=self.id,
            name=self.name,
            uid=self.uid)


def get_database_database_catalog(name: Optional[_builtins.str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseDatabaseCatalogResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single Database Catalog.

    ## Example Usage

    Referring to a Database Catalog by name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_database_database_catalog(name="my-database-catalog")
    ```


    :param _builtins.str name: The name of the catalog in UC
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getDatabaseDatabaseCatalog:getDatabaseDatabaseCatalog', __args__, opts=opts, typ=GetDatabaseDatabaseCatalogResult).value

    return AwaitableGetDatabaseDatabaseCatalogResult(
        create_database_if_not_exists=pulumi.get(__ret__, 'create_database_if_not_exists'),
        database_instance_name=pulumi.get(__ret__, 'database_instance_name'),
        database_name=pulumi.get(__ret__, 'database_name'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        uid=pulumi.get(__ret__, 'uid'))
def get_database_database_catalog_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseDatabaseCatalogResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single Database Catalog.

    ## Example Usage

    Referring to a Database Catalog by name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_database_database_catalog(name="my-database-catalog")
    ```


    :param _builtins.str name: The name of the catalog in UC
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getDatabaseDatabaseCatalog:getDatabaseDatabaseCatalog', __args__, opts=opts, typ=GetDatabaseDatabaseCatalogResult)
    return __ret__.apply(lambda __response__: GetDatabaseDatabaseCatalogResult(
        create_database_if_not_exists=pulumi.get(__response__, 'create_database_if_not_exists'),
        database_instance_name=pulumi.get(__response__, 'database_instance_name'),
        database_name=pulumi.get(__response__, 'database_name'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        uid=pulumi.get(__response__, 'uid')))
